==> lg-rotate-1.0.0.tgz: package/README.md <==
![travis](https://travis-ci.org/sachinchoolur/lg-rotate.svg?branch=master)
![bower](https://img.shields.io/bower/v/lg-rotate.svg)
![npm](https://img.shields.io/npm/v/lg-rotate.svg)

# Rotate module for [lightGallery](http://sachinchoolur.github.io/lightGallery/)
A customizable, modular, responsive, lightbox gallery plugin for jQuery.
![lightgallery](https://raw.githubusercontent.com/sachinchoolur/lightGallery/master/lib/lg.png)

Main features
---

* Rotate right.
* Rotate left.
* Flip horizontal.
* Filp vertical.
 
Browser support
---
lightgallery supports all major browsers including IE 9 and above..


Installation
---
#### Install with Bower

You can install lightgallery rotate plugin using the [Bower](http://bower.io) package manager.

```sh
$ bower install lg-rotate --save
```

#### npm

You can also find lightgallery rotate plugin on [npm](http://npmjs.org).

```sh
$ npm install lg-rotate
```
#### Download from Github

You can also directly download lg-rotate from github.

#### CDN
If you prefer to use a CDN you can load files via [jsdelivr](https://www.jsdelivr.com/projects/lg-rotate)

#### Include Javascript files
Include lg-rotate plugin after lightgallery.min.js.
``` html
<body>
   ---
    <!-- Include lightGallery -->
    <script src="js/lightgallery.min.js"></script>
    
    <!-- Include lg-rotate -->
    <script src="js/lg-rotate.min.js"></script>
    
    <!-- Include other lightgallery plugins (Optional) -->
    <script src="js/lg-thumbnail.min.js"></script>
</body>  
```

[Demos](http://sachinchoolur.github.io/lightGallery/demos/rotate.html)
----
  
[Docs](http://sachinchoolur.github.io/lightGallery/docs/api.html#lg-rotate)
-----

License
---

#### Commercial license
If you want to use lightGallery to develop commercial sites, themes, projects, and applications, the Commercial license is the appropriate license. With this option, your source code is kept proprietary. Purchase a lightGallery Commercial License at [uplabs.com/posts/lightgallery-plugin](https://www.uplabs.com/posts/lightgallery-plugin)

#### Open source license

If you are creating an open source application under a license compatible with the GNU GPL license v3, you may use this project under the terms of the GPLv3.

==> lg-rotate-1.2.1.tgz: package/README.md <==
![travis](https://travis-ci.org/sachinchoolur/lg-rotate.svg?branch=master)
![npm](https://img.shields.io/npm/v/lg-rotate.svg)

# Rotate module for [lightGallery](http://sachinchoolur.github.io/lightGallery/)
A customizable, modular, responsive, lightbox gallery plugin for jQuery.
![lightgallery](https://raw.githubusercontent.com/sachinchoolur/lightGallery/master/lib/lg.png)

Main features
---

* Rotate right.
* Rotate left.
* Flip horizontal.
* Filp vertical.
 
Browser support
---
lightgallery supports all major browsers including IE 9 and above..


Installation
---

#### Install with npm

You can install lightgallery rotate plugin using the [npm](http://npmjs.org) package manager.

```sh
$ npm install lg-rotate
```
#### Download from Github

You can also directly download lg-rotate from github.

#### CDN
If you prefer to use a CDN you can load files via [jsdelivr](https://www.jsdelivr.com/projects/lg-rotate)

#### Include Javascript files
Include lg-rotate plugin after lightgallery.min.js.
``` html
<body>
   ---
    <!-- Include lightGallery -->
    <script src="js/lightgallery.min.js"></script>
    
    <!-- Include lg-rotate -->
    <script src="js/lg-rotate.min.js"></script>
    
    <!-- Include other lightgallery plugins (Optional) -->
    <script src="js/lg-thumbnail.min.js"></script>
</body>  
```

[Demos](http://sachinchoolur.github.io/lightGallery/)
----
  
[Docs](http://sachinchoolur.github.io/lightGallery/docs/api.html#lg-rotate)
-----

License
---

#### Commercial license
If you want to use lightGallery to develop commercial sites, themes, projects, and applications, the Commercial license is the appropriate license. With this option, your source code is kept proprietary. Purchase a lightGallery Commercial License at [uplabs.com/posts/lightgallery-plugin](https://www.uplabs.com/posts/lightgallery-plugin)

#### Open source license

If you are creating an open source application under a license compatible with the GNU GPL license v3, you may use this project under the terms of the GPLv3.
